@@ -229,61 +229,6 @@ godot_versions = {
     ':3.2.3::linux:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.2.3/mono/Godot_v3.2.3-stable_mono_x11_64.zip',
     ':3.2.3::windows:32:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.2.3/mono/Godot_v3.2.3-stable_mono_win32.zip',
     ':3.2.3::windows:64:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.2.3/mono/Godot_v3.2.3-stable_mono_win64.zip',
-# 3.2.4 rc1
-    ':3.2.4:rc1:darwin::'           : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc1/Godot_v3.2.4-rc1_osx.universal.zip',
-    ':3.2.4:rc1:linux:32:'          : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc1/Godot_v3.2.4-rc1_x11.32.zip',
-    ':3.2.4:rc1:linux:64:'          : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc1/Godot_v3.2.4-rc1_x11.64.zip',
-    ':3.2.4:rc1:windows:64:'        : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc1/Godot_v3.2.4-rc1_win64.exe.zip',
-    ':3.2.4:rc1:windows:32:'        : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc1/Godot_v3.2.4-rc1_win32.exe.zip',
-    ':3.2.4:rc1:darwin::mono'       : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc1/mono/Godot_v3.2.4-rc1_mono_osx.64.zip',
-    ':3.2.4:rc1:linux:32:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc1/mono/Godot_v3.2.4-rc1_mono_x11_32.zip',
-    ':3.2.4:rc1:linux:64:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc1/mono/Godot_v3.2.4-rc1_mono_x11_64.zip',
-    ':3.2.4:rc1:windows:64:mono'    : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc1/mono/Godot_v3.2.4-rc1_mono_win32.zip',
-    ':3.2.4:rc1:windows:32:mono'    : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc1/mono/Godot_v3.2.4-rc1_mono_win64.zip',
-# 3.2.4 rc2
-    ':3.2.4:rc2:darwin::'           : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc2/Godot_v3.2.4-rc2_osx.universal.zip',
-    ':3.2.4:rc2:linux:32:'          : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc2/Godot_v3.2.4-rc2_x11.32.zip',
-    ':3.2.4:rc2:linux:64:'          : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc2/Godot_v3.2.4-rc2_x11.64.zip',
-    ':3.2.4:rc2:windows:64:'        : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc2/Godot_v3.2.4-rc2_win64.exe.zip',
-    ':3.2.4:rc2:windows:32:'        : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc2/Godot_v3.2.4-rc2_win32.exe.zip',
-    ':3.2.4:rc2:darwin::mono'       : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rdcc2/mono/Godot_v3.2.4-rc2_mono_osx.64.zip',
-    ':3.2.4:rc2:linux:32:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc2/mono/Godot_v3.2.4-rc2_mono_x11_32.zip',
-    ':3.2.4:rc2:linux:64:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc2/mono/Godot_v3.2.4-rc2_mono_x11_64.zip',
-    ':3.2.4:rc2:windows:64:mono'    : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc2/mono/Godot_v3.2.4-rc2_mono_win32.zip',
-    ':3.2.4:rc2:windows:32:mono'    : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc2/mono/Godot_v3.2.4-rc2_mono_win64.zip',
-# 3.2.4 rc3
-    ':3.2.4:rc3:darwin::'           : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc3/Godot_v3.2.4-rc3_osx.universal.zip',
-    ':3.2.4:rc3:linux:32:'          : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc3/Godot_v3.2.4-rc3_x11.32.zip',
-    ':3.2.4:rc3:linux:64:'          : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc3/Godot_v3.2.4-rc3_x11.64.zip',
-    ':3.2.4:rc3:windows:64:'        : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc3/Godot_v3.2.4-rc3_win64.exe.zip',
-    ':3.2.4:rc3:windows:32:'        : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc3/Godot_v3.2.4-rc3_win32.exe.zip',
-    ':3.2.4:rc3:darwin::mono'       : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc3/mono/Godot_v3.2.4-rc3_mono_osx.64.zip',
-    ':3.2.4:rc3:linux:32:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc3/mono/Godot_v3.2.4-rc3_mono_x11_32.zip',
-    ':3.2.4:rc3:linux:64:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc3/mono/Godot_v3.2.4-rc3_mono_x11_64.zip',
-    ':3.2.4:rc3:windows:64:mono'    : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc3/mono/Godot_v3.2.4-rc3_mono_win32.zip',
-    ':3.2.4:rc3:windows:32:mono'    : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc3/mono/Godot_v3.2.4-rc3_mono_win64.zip',
-# 3.2.4 rc4
-    ':3.2.4:rc4:darwin::'           : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc4/Godot_v3.2.4-rc4_osx.universal.zip',
-    ':3.2.4:rc4:linux:32:'          : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc4/Godot_v3.2.4-rc4_x11.32.zip',
-    ':3.2.4:rc4:linux:64:'          : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc4/Godot_v3.2.4-rc4_x11.64.zip',
-    ':3.2.4:rc4:windows:64:'        : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc4/Godot_v3.2.4-rc4_win64.exe.zip',
-    ':3.2.4:rc4:windows:32:'        : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc4/Godot_v3.2.4-rc4_win32.exe.zip',
-    ':3.2.4:rc4:darwin::mono'       : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc4/mono/Godot_v3.2.4-rc4_mono_osx.64.zip',
-    ':3.2.4:rc4:linux:32:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc4/mono/Godot_v3.2.4-rc4_mono_x11_32.zip',
-    ':3.2.4:rc4:linux:64:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc4/mono/Godot_v3.2.4-rc4_mono_x11_64.zip',
-    ':3.2.4:rc4:windows:64:mono'    : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc4/mono/Godot_v3.2.4-rc4_mono_win32.zip',
-    ':3.2.4:rc4:windows:32:mono'    : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc4/mono/Godot_v3.2.4-rc4_mono_win64.zip',
-# 3.2.4 rc5
-    ':3.2.4:rc5:darwin::'           : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc5/Godot_v3.2.4-rc5_osx.universal.zip',
-    ':3.2.4:rc5:linux:32:'          : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc5/Godot_v3.2.4-rc5_x11.32.zip',
-    ':3.2.4:rc5:linux:64:'          : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc5/Godot_v3.2.4-rc5_x11.64.zip',
-    ':3.2.4:rc5:windows:64:'        : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc5/Godot_v3.2.4-rc5_win64.exe.zip',
-    ':3.2.4:rc5:windows:32:'        : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc5/Godot_v3.2.4-rc5_win32.exe.zip',
-    ':3.2.4:rc5:darwin::mono'       : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc5/mono/Godot_v3.2.4-rc5_mono_osx.64.zip',
-    ':3.2.4:rc5:linux:32:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc5/mono/Godot_v3.2.4-rc5_mono_x11_32.zip',
-    ':3.2.4:rc5:linux:64:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc5/mono/Godot_v3.2.4-rc5_mono_x11_64.zip',
-    ':3.2.4:rc5:windows:64:mono'    : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc5/mono/Godot_v3.2.4-rc5_mono_win32.zip',
-    ':3.2.4:rc5:windows:32:mono'    : 'https://downloads.tuxfamily.org/godotengine/3.2.4/rc5/mono/Godot_v3.2.4-rc5_mono_win64.zip',
 # 3.3
     ':3.3::darwin::'                : 'https://downloads.tuxfamily.org/godotengine/3.3/Godot_v3.3-stable_osx.universal.zip',
     ':3.3::linux:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.3/Godot_v3.3-stable_x11.32.zip',
@@ -295,26 +240,26 @@ godot_versions = {
     ':3.3::linux:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.3/mono/Godot_v3.3-stable_mono_x11_64.zip',
     ':3.3::windows:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.3/mono/Godot_v3.3-stable_mono_win32.zip',
     ':3.3::windows:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.3/mono/Godot_v3.3-stable_mono_win64.zip',
-# 3.3 rc6
-    ':3.3:rc6:darwin::'             : 'https://downloads.tuxfamily.org/godotengine/3.3/rc6/Godot_v3.3-rc6_osx.universal.zip',
-    ':3.3:rc6:linux:32:'            : 'https://downloads.tuxfamily.org/godotengine/3.3/rc6/Godot_v3.3-rc6_x11.32.zip',
-    ':3.3:rc6:linux:64:'            : 'https://downloads.tuxfamily.org/godotengine/3.3/rc6/Godot_v3.3-rc6_x11.64.zip',
-    ':3.3:rc6:windows:64:'          : 'https://downloads.tuxfamily.org/godotengine/3.3/rc6/Godot_v3.3-rc6_win64.exe.zip',
-    ':3.3:rc6:windows:32:'          : 'https://downloads.tuxfamily.org/godotengine/3.3/rc6/Godot_v3.3-rc6_win32.exe.zip',
-    ':3.3:rc6:darwin::mono'         : 'https://downloads.tuxfamily.org/godotengine/3.3/rc6/mono/Godot_v3.3-rc6_mono_osx.64.zip',
-    ':3.3:rc6:linux:32:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.3/rc6/mono/Godot_v3.3-rc6_mono_x11_32.zip',
-    ':3.3:rc6:linux:64:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.3/rc6/mono/Godot_v3.3-rc6_mono_x11_64.zip',
-    ':3.3:rc6:windows:64:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.3/rc6/mono/Godot_v3.3-rc6_mono_win32.zip',
-    ':3.3:rc6:windows:32:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.3/rc6/mono/Godot_v3.3-rc6_mono_win64.zip',
-# 3.3 rc7
-    ':3.3:rc7:darwin::'             : 'https://downloads.tuxfamily.org/godotengine/3.3/rc7/Godot_v3.3-rc7_osx.universal.zip',
-    ':3.3:rc7:linux:32:'            : 'https://downloads.tuxfamily.org/godotengine/3.3/rc7/Godot_v3.3-rc7_x11.32.zip',
-    ':3.3:rc7:linux:64:'            : 'https://downloads.tuxfamily.org/godotengine/3.3/rc7/Godot_v3.3-rc7_x11.64.zip',
-    ':3.3:rc7:windows:64:'          : 'https://downloads.tuxfamily.org/godotengine/3.3/rc7/Godot_v3.3-rc7_win64.exe.zip',
-    ':3.3:rc7:windows:32:'          : 'https://downloads.tuxfamily.org/godotengine/3.3/rc7/Godot_v3.3-rc7_win32.exe.zip',
-    ':3.3:rc7:darwin::mono'         : 'https://downloads.tuxfamily.org/godotengine/3.3/rc7/mono/Godot_v3.3-rc7_mono_osx.64.zip',
-    ':3.3:rc7:linux:32:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.3/rc7/mono/Godot_v3.3-rc7_mono_x11_32.zip',
-    ':3.3:rc7:linux:64:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.3/rc7/mono/Godot_v3.3-rc7_mono_x11_64.zip',
-    ':3.3:rc7:windows:64:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.3/rc7/mono/Godot_v3.3-rc7_mono_win32.zip',
-    ':3.3:rc7:windows:32:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.3/rc7/mono/Godot_v3.3-rc7_mono_win64.zip',
+# 3.3.1
+    ':3.3.1::darwin::'                : 'https://downloads.tuxfamily.org/godotengine/3.3.1/Godot_v3.3.1-stable_osx.universal.zip',
+    ':3.3.1::linux:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.3.1/Godot_v3.3.1-stable_x11.32.zip',
+    ':3.3.1::linux:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.3.1/Godot_v3.3.1-stable_x11.64.zip',
+    ':3.3.1::windows:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.3.1/Godot_v3.3.1-stable_win64.exe.zip',
+    ':3.3.1::windows:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.3.1/Godot_v3.3.1-stable_win32.exe.zip',
+    ':3.3.1::darwin::mono'            : 'https://downloads.tuxfamily.org/godotengine/3.3.1/mono/Godot_v3.3.1-stable_mono_osx.64.zip',
+    ':3.3.1::linux:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.3.1/mono/Godot_v3.3.1-stable_mono_x11_32.zip',
+    ':3.3.1::linux:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.3.1/mono/Godot_v3.3.1-stable_mono_x11_64.zip',
+    ':3.3.1::windows:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.3.1/mono/Godot_v3.3.1-stable_mono_win32.zip',
+    ':3.3.1::windows:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.3.1/mono/Godot_v3.3.1-stable_mono_win64.zip',
+# 3.3.2
+    ':3.3.2::darwin::'                : 'https://downloads.tuxfamily.org/godotengine/3.3.2/Godot_v3.3.2-stable_osx.universal.zip',
+    ':3.3.2::linux:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.3.2/Godot_v3.3.2-stable_x11.32.zip',
+    ':3.3.2::linux:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.3.2/Godot_v3.3.2-stable_x11.64.zip',
+    ':3.3.2::windows:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.3.2/Godot_v3.3.2-stable_win64.exe.zip',
+    ':3.3.2::windows:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.3.2/Godot_v3.3.2-stable_win32.exe.zip',
+    ':3.3.2::darwin::mono'            : 'https://downloads.tuxfamily.org/godotengine/3.3.2/mono/Godot_v3.3.2-stable_mono_osx.64.zip',
+    ':3.3.2::linux:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.3.2/mono/Godot_v3.3.2-stable_mono_x11_32.zip',
+    ':3.3.2::linux:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.3.2/mono/Godot_v3.3.2-stable_mono_x11_64.zip',
+    ':3.3.2::windows:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.3.2/mono/Godot_v3.3.2-stable_mono_win32.zip',
+    ':3.3.2::windows:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.3.2/mono/Godot_v3.3.2-stable_mono_win64.zip',
 }
